==> wow-core-3.4.0-sources.jar: me/ahoo/wow/command/CommandExceptions.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.ahoo.wow.command

import jakarta.validation.ConstraintViolation
import me.ahoo.wow.api.command.CommandMessage
import me.ahoo.wow.api.exception.BindingError
import me.ahoo.wow.api.exception.ErrorInfo
import me.ahoo.wow.api.modeling.AggregateId
import me.ahoo.wow.api.modeling.NamedAggregate
import me.ahoo.wow.exception.ErrorCodes.COMMAND_VALIDATION
import me.ahoo.wow.exception.ErrorCodes.DUPLICATE_REQUEST_ID
import me.ahoo.wow.exception.WowException

class DuplicateRequestIdException(val aggregateId: AggregateId, val requestId: String, cause: Throwable? = null) :
    WowException(
        errorCode = DUPLICATE_REQUEST_ID,
        errorMsg = "Duplicate request ID[$requestId].",
        cause = cause,
    ),
    NamedAggregate by aggregateId

class CommandValidationException(
    val commandMessage: CommandMessage<*>,
    val constraintViolations: Set<ConstraintViolation<*>>
) :
    WowException(
        errorCode = COMMAND_VALIDATION,
        errorMsg = "Command validation failed.",
    ),
    NamedAggregate by commandMessage,
    ErrorInfo {

    override val bindingErrors: List<BindingError> by lazy {
        constraintViolations.map {
            BindingError(it.propertyPath.toString(), it.message)
        }
    }
}

class CommandResultException(val commandResult: CommandResult, cause: Throwable? = null) :
    WowException(errorCode = commandResult.errorCode, errorMsg = commandResult.errorMsg, cause)

==> wow-core-3.5.0-sources.jar: me/ahoo/wow/command/CommandExceptions.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.ahoo.wow.command

import jakarta.validation.ConstraintViolation
import me.ahoo.wow.api.command.CommandMessage
import me.ahoo.wow.api.exception.BindingError
import me.ahoo.wow.api.exception.ErrorInfo
import me.ahoo.wow.api.modeling.AggregateId
import me.ahoo.wow.api.modeling.NamedAggregate
import me.ahoo.wow.exception.ErrorCodes.COMMAND_VALIDATION
import me.ahoo.wow.exception.ErrorCodes.DUPLICATE_REQUEST_ID
import me.ahoo.wow.exception.WowException

class DuplicateRequestIdException(val aggregateId: AggregateId, val requestId: String, cause: Throwable? = null) :
    WowException(
        errorCode = DUPLICATE_REQUEST_ID,
        errorMsg = "Duplicate request ID[$requestId].",
        cause = cause,
    ),
    NamedAggregate by aggregateId

class CommandValidationException(
    val commandMessage: CommandMessage<*>,
    val constraintViolations: Set<ConstraintViolation<*>>
) :
    WowException(
        errorCode = COMMAND_VALIDATION,
        errorMsg = "Command validation failed.",
    ),
    NamedAggregate by commandMessage,
    ErrorInfo {
    override val bindingErrors: List<BindingError> by lazy {
        constraintViolations.map {
            BindingError(it.propertyPath.toString(), it.message)
        }
    }
}

class CommandResultException(val commandResult: CommandResult, cause: Throwable? = null) :
    WowException(
        errorCode = commandResult.errorCode,
        errorMsg = commandResult.errorMsg,
        cause = cause,
        bindingErrors = commandResult.bindingErrors
    )
